==> v3-pack-center-1.0.1.tgz: package/src/updater/ComponentUpdater.js <==
const path = require('path');
const ioUtils = require('../utils/IOUtils');
const md5File = require('md5-file');
let componentsDir = path.resolve(__dirname, '../../components');

class ComponentUpdater {

    constructor(src) {
        this.src = src;
    }

    udpate() {
        return new Promise((resolve, reject) => {
            try {
                let start = Date.now();
                let metadataPath = path.resolve(this.src, 'src/components/metadata.json');
                let metadata = require(metadataPath);
                let componentCode = metadata[0].code;
                let selfMetadataPath = path.resolve(__dirname,"../../metadata.json");
                let selfMetadata = require(selfMetadataPath);
                let fileMetadata = selfMetadata.filemetadata || {};
                let sourcePath = path.resolve(this.src, 'src');
                let promise = ioUtils.copyDirWithFilter(sourcePath, path.resolve(componentsDir, componentCode, "src"), (absPath,distPath) => {
                    let key = path.join(componentCode, "src", path.relative(sourcePath, absPath));
                    let md5 = md5File.sync(absPath);
                    if (fileMetadata[key] !== md5) {
                        fileMetadata[key] = md5;
                        return true;
                    } else {
                        return false;
                    }
                });
                promise.then(() => {
                    selfMetadata.filemetadata = fileMetadata;
                    ioUtils.write(selfMetadataPath, JSON.stringify(selfMetadata, null, "\t"));
                    console.log(`更新构件【${componentCode}】源码完成，耗时【${Date.now()-start}】毫秒！`);
                    resolve();
                }).catch(err => {
                    reject(err);
                });
            } catch (err) {
                reject(err);
            }
        });
    }

}

module.exports = ComponentUpdater;

==> v3-pack-center-1.0.8.tgz: package/src/updater/ComponentUpdater.js <==
const path = require('path');
const ioUtils = require('../utils/IOUtils');
const fileUtils = require('../utils/FileUtils');
const md5File = require('md5-file');
let componentsDir = path.resolve(__dirname, '../../components');

class ComponentUpdater {

    constructor(src) {
        this.src = src;
    }

    udpate() {
        return new Promise((resolve, reject) => {
            try {
                let start = Date.now();
                let metadataPath = path.resolve(this.src, 'src/components/metadata.json');
                let metadata = require(metadataPath);
                let componentCode = metadata[0].code;
                let selfMetadataPath = path.resolve(__dirname,"../../metadata.json");
                let selfMetadata = require(selfMetadataPath);
                let fileMetadata = selfMetadata.filemetadata || {};
                let sourcePath = path.resolve(this.src, 'src');
                let promise = ioUtils.copyDirWithFilter(sourcePath, path.resolve(componentsDir,componentCode, "src"), (absPath,distPath) => {
                    let key = path.join(componentCode, "src", path.relative(sourcePath, absPath));
                    let md5 = md5File.sync(absPath);
                    if (fileMetadata[key] !== md5||!fileUtils.exists(distPath)) {
                        fileMetadata[key] = md5;
                        return true;
                    } else {
                        return false;
                    }
                });
                promise.then((distFiles) => {
                    if(distFiles&&distFiles.length>0){
                        //清除缓存
                        distFiles.forEach(file => {
                            delete require.cache[file];
                        });
                    }
                    selfMetadata.filemetadata = fileMetadata;
                    ioUtils.write(selfMetadataPath, JSON.stringify(selfMetadata, null, "\t"));
                    console.log(`更新构件【${componentCode}】源码完成，耗时【${Date.now()-start}】毫秒！`);
                    resolve();
                }).catch(err => {
                    reject(err);
                });
            } catch (err) {
                reject(err);
            }
        });
    }

}

module.exports = ComponentUpdater;
